.. :changelog:

History
-------

0.2.0 (2014-11-01)
---------------------

* Having a TPA is not longer mandatory to provide a micro payments widget. Parameters app_id and app_secret are now optional. 

0.0.1 (2014-10-18)
---------------------

* First release on PyPI.
* Includes:
    * iframe widget
    * div widget